package onthestage.es.onthestage.adapters;
/*
        Autor: Carlos Tarazona Tárrega.
        Licencia: Copyright 2018. Se permite el estudio y modificación del fichero citando las fuentes
*/
import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.support.v7.app.AlertDialog;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Switch;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.List;

import onthestage.es.onthestage.R;
import onthestage.es.onthestage.model.FiltroContent;
import onthestage.es.onthestage.utils.AppData;

public class BusquedasAdapter extends RecyclerView.Adapter<BusquedasAdapter.MyViewHolder> {
    private Context context;
    private Activity activity;
    final BusquedasAdapter busquedasAdapter;

    public BusquedasAdapter(Context context,Activity activity) {
        this.context = context;
        this.activity = activity;
        busquedasAdapter = this;
    }

    public void setDataSet(List<FiltroContent.Filtro> filtros){
        FiltroContent.filtros = new ArrayList<FiltroContent.Filtro>(filtros);
        this.notifyDataSetChanged();
    }

    // Create new views (invoked by the layout manager)
    @Override
    public BusquedasAdapter.MyViewHolder onCreateViewHolder(ViewGroup parent,
                                                             int viewType) {
        // create a new view
        View v = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.search_list_item, parent, false);
        // set the view's size, margins, paddings and layout parameters

        BusquedasAdapter.MyViewHolder vh = new BusquedasAdapter.MyViewHolder(v);
        return vh;
    }

    // Replace the contents of a view (invoked by the layout manager)
    @Override
    public void onBindViewHolder(final BusquedasAdapter.MyViewHolder holder, final int position) {
        final FiltroContent.Filtro filtro = FiltroContent.filtros.get(position);
        holder.tvNombre.setText(FiltroContent.filtros.get(position).getNombre());
        String query = "";
        if(!filtro.getQuien().equals("")){
            query += context.getString(R.string.artista) + ": " +filtro.getQuien()+", ";
        }
        if(!filtro.getCuando().equals("")){
            String modificador = "";
            modificador += context.getString(R.string.when);
            modificador= context.getString(R.string.hasta_dia)+" ";
            if(filtro.getSumarCuando()<0){
                modificador=context.getString(R.string.el_dia)+" ";
            }
            query += modificador + ": " + AppData.sumarDiasAFechaUser(filtro.getCuando(),filtro.getSumarCuando())+", ";
        }

        String[] ques = filtro.getQues().split(AppData.SEPARATOR_FILTER);
        if(ques.length >0 && !ques[0].equals("")){
            query += context.getString(R.string.what) + ": ";
            for(int i = 0; i<ques.length;i++){
                query += ques[i]+", ";
            }
        }
        String[] precios = filtro.getPrecios().split(AppData.SEPARATOR_FILTER);
        if(precios.length>0 && !precios[0].equals("")){
            query += context.getString(R.string.precio) + ": ";
            for(int i = 0; i<precios.length;i++){
                String text="";
                switch (precios[i]){
                    case "0":
                        text=context.getString(R.string.gratis);
                        break;
                    case "5":
                        text=context.getString(R.string.hasta_precio)+" 5€";
                        break;
                    case "10":
                        text=context.getString(R.string.hasta_precio)+" 10€";
                        break;
                    case "15":
                        text=context.getString(R.string.hasta_precio)+" 15€";
                        break;
                    case "20":
                        text=context.getString(R.string.masde_precio)+" 15€";
                        break;

                }
                query += text+", ";
            }
        }


        holder.tvTipos.setText(query.substring(0,query.length()-2));

        holder.tvModificar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(context);
                final EditText et = new EditText(context);
                et.setId(R.id.edit_provisional_busqueda);
                alertDialogBuilder
                        .setMessage(context.getResources().getString(R.string.change_name))
                        .setTitle(context.getResources().getString(R.string.choose_new_name))
                        .setView(et)
                        .setCancelable(false)
                        .setPositiveButton(R.string.aceptar,
                                new DialogInterface.OnClickListener() {
                                    public void onClick(DialogInterface dialog, int id) {
                                        String nombre="NAME";
                                        nombre = et.getText().toString();
                                        FiltroContent.filtros.get(position).setNombre(nombre);
                                        FiltroContent.filtros.get(position).save();
                                        holder.tvNombre.setText(nombre);
                                        dialog.dismiss();
                                    }
                                });
                alertDialogBuilder.setNegativeButton(R.string.cancel,
                        new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int id) {
                                dialog.cancel();
                            }
                        });
                AlertDialog alert = alertDialogBuilder.create();
                alert.show();
            }
        });
        final int pos = position;

        holder.tvEliminar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(context);
                alertDialogBuilder
                        .setMessage(context.getResources().getString(R.string.confirm_delete))
                        .setTitle(context.getResources().getString(R.string.delete))
                        .setCancelable(false)
                        .setPositiveButton(R.string.aceptar,
                                new DialogInterface.OnClickListener() {
                                    public void onClick(DialogInterface dialog, int id) {
                                        FiltroContent.filtros.get(pos).delete();
                                        FiltroContent.filtros.remove(pos);
                                        FiltroContent.filtros = FiltroContent.getFiltros();
                                        busquedasAdapter.notifyDataSetChanged();
                                        dialog.dismiss();
                                    }
                                });
                alertDialogBuilder.setNegativeButton(R.string.cancel,
                        new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int id) {
                                dialog.cancel();
                            }
                        });
                AlertDialog alert = alertDialogBuilder.create();
                alert.show();



            }
        });

        holder.sNotificar.setChecked(FiltroContent.filtros.get(position).getNotificaciones());

        holder.sNotificar.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                FiltroContent.filtros.get(position).setNotificaciones(isChecked);
                FiltroContent.filtros.get(position).save();
            }
        });




    }

    // Return the size of your dataset (invoked by the layout manager)
    @Override
    public int getItemCount() {
        return FiltroContent.filtros.size();
    }

    public class MyViewHolder extends RecyclerView.ViewHolder{
        public final View mView;
        public final TextView tvNombre;
        public final TextView tvTipos;
        public final TextView tvModificar;
        public final TextView tvEliminar;
        public final Switch sNotificar;

        public MyViewHolder(View view) {
            super(view);
            mView = view;
            tvNombre = (TextView) view.findViewById(R.id.nombre_busqueda);
            tvTipos = (TextView) view.findViewById(R.id.tipo_busqueda);
            tvModificar = (TextView) view.findViewById(R.id.search_change_name);
            tvEliminar = (TextView) view.findViewById(R.id.search_delete);
            sNotificar = (Switch) view.findViewById(R.id.switch_notificar);
        }
    }
}
