package onthestage.es.onthestage.adapters;
/*
* Author Carlos Tarazona Tárrega
* copyright 2018
* Adaptador para rellenar el listado de eventos tras la búsqueda filtrada
* También muestra el diálogo de ordenación*/
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.design.widget.Snackbar;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import org.json.JSONException;
import org.json.JSONObject;

import java.net.MalformedURLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import onthestage.es.onthestage.EventoArtistaLocal;
import onthestage.es.onthestage.R;
import onthestage.es.onthestage.Service.LocationService;
import onthestage.es.onthestage.Service.PostAsync;
import onthestage.es.onthestage.Service.TaskDelegateService;
import onthestage.es.onthestage.model.EventosContent;
import onthestage.es.onthestage.utils.AppData;

public class EventListAdapter extends RecyclerView.Adapter<EventListAdapter.EventListHolder>{
    private Context context;
    private Activity activity;
    private List<EventosContent.EventoMin> eventos;

    public EventListAdapter(Context context, Activity activity, List<EventosContent.EventoMin> mEventos) {
        this.context = context;
        this.activity = activity;
        this.eventos = new ArrayList<EventosContent.EventoMin>(mEventos);
        this.notifyDataSetChanged();
    }

    public List<EventosContent.EventoMin> getEventos() {
        return eventos;
    }

    public void setEventos(List<EventosContent.EventoMin> eventos) {
        this.eventos = eventos;
        this.notifyDataSetChanged();
    }

    @NonNull
    @Override
    public EventListHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View v = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.event_list_item, parent, false);
        // set the view's size, margins, paddings and layout parameters

        EventListHolder vh = new EventListHolder(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull EventListHolder holder, final int position) {
        final EventosContent.EventoMin e = eventos.get(position);


        LocationService ls = LocationService.getLocationManager(context);
        String distancia = context.getResources().getString(R.string.sin_datos);
        if(ls.locationServiceAvailable){
            double dist = AppData.getDistancia(ls.latitude,ls.longitude,e.getLatitud(),e.getLongitud());
            String unidad = " m";
            if(dist>1000){
                dist = dist/1000;
                unidad = " km";
            }
            dist = Math.round(dist*100.0)/100.0;
            distancia = ""+dist+unidad;
        }

        if(e.getNombre().length()>=20){
            holder.nombre.setText("" + e.getNombre().substring(0,20)+"...");
        }else{
            holder.nombre.setText("" + e.getNombre());
        }
         if(e.getLocal().length()>=15){
            holder.local.setText("" + e.getLocal().toUpperCase().substring(0,15)+"...");
        }else{
            holder.local.setText("" + e.getLocal().toUpperCase());
        }

        holder.precio.setText(": " + e.getPrecio() + " €");

        holder.fecha.setText(": " + e.getDia());

        String info = e.getTelefono();
        if(info==null || info.equals("") ){
            info=context.getResources().getString(R.string.sin_informacion);
        }
        holder.telefono.setText(": " + info);

        holder.distancia.setText(": " + distancia);

        holder.favorito.setSelected(e.getEsFavorito());
        holder.favorito.setText(""+e.getNumFavoritos());

        holder.loTelefono.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(Intent.ACTION_DIAL);
                intent.setData(Uri.parse("tel:"+AppData.formatPhoneNumber(e.getTelefono(),context).replace(" ","")));
                context.startActivity(intent);
            }
        });

        holder.compartir.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                AppData.compartirEvento(context, e, null);
            }
        });

        holder.favorito.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if(v.isSelected()){
                    cambiarFavorito(false,(Button) v,e.getId());
                }else{
                    cambiarFavorito(true,(Button) v,e.getId());
                }
            }
        });

        holder.navegar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // Create a Uri from an intent string. Use the result to create an Intent.
                //Uri gmmIntentUri = Uri.parse("google.streetview:cbll="+e.getLatitud()+","+e.getLongitud());
                Uri gmmIntentUri = Uri.parse("geo:"+e.getLatitud()+","+e.getLongitud()+"?z=19&q="+Uri.encode(e.getLocal()));

                // Create an Intent from gmmIntentUri. Set the action to ACTION_VIEW
                Intent mapIntent = new Intent(Intent.ACTION_VIEW, gmmIntentUri);
                // Make the Intent explicit by setting the Google Maps package
                mapIntent.setPackage("com.google.android.apps.maps");

                // Attempt to start an activity that can handle the Intent
                context.startActivity(mapIntent);
            }
        });

        String foto = e.getFoto();
        if(foto==null || foto.equals("")){
            foto= AppData.NO_IMAGE;
        }
        AppData.getGlide(context,foto,holder.foto);

        holder.foto.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(context,EventoArtistaLocal.class);
                intent.putExtra(AppData.ARG_ID_EVENTO,e.getId());
                context.startActivity(intent);
            }
        });

        String artistas = AppData.ucFirst(eventos.get(position).getArtistas().get(0).toLowerCase());
        if(eventos.get(position).getArtistas().size()>1){
            artistas += ", +...";
        }
        holder.nombreArtista.setText(artistas);

        if(eventos.get(position).getTickets() == null || eventos.get(position).getTickets().equals("")){
            holder.ticket.setSelected(false);
        }else{
            holder.ticket.setSelected(true);
        }

        holder.ticket.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if(v.isSelected()){
                    String url = eventos.get(position).getTickets();
                    try{
                        context.startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(url)));
                    }catch (Exception e){
                        Toast.makeText(context,context.getString(R.string.something_was_wrong),Toast.LENGTH_SHORT).show();
                        Log.e("EVENTLISTADAPTER", e.getLocalizedMessage());

                    }

                }
            }
        });

    }

    @Override
    public int getItemCount() {
        return eventos.size();
    }

    public class EventListHolder extends RecyclerView.ViewHolder{
        public final ImageView foto;
        public final TextView nombre;
        public final TextView nombreArtista;
        public final TextView fecha;
        public final TextView precio;
        public final TextView telefono;
        public final TextView local;
        public final TextView distancia;
        public final ImageButton compartir;
        public final Button favorito;
        public final ImageButton ticket;
        public final ImageButton navegar;
        public final LinearLayout loTelefono;

        public EventListHolder(View itemView) {
            super(itemView);
            foto = (ImageView) itemView.findViewById(R.id.event_item_foto);
            nombre = (TextView) itemView.findViewById(R.id.event_item_nartista);
            nombreArtista = (TextView) itemView.findViewById(R.id.event_item_artistas);
            fecha = (TextView) itemView.findViewById(R.id.event_item_fecha);
            telefono = (TextView) itemView.findViewById(R.id.evento_telefono);
            precio = (TextView) itemView.findViewById(R.id.event_item_precio);
            local = (TextView) itemView.findViewById(R.id.event_item_local);
            distancia = (TextView) itemView.findViewById(R.id.event_item_distancia);
            compartir = (ImageButton) itemView.findViewById(R.id.evento_share);
            favorito = (Button) itemView.findViewById(R.id.evento_favorito);
            navegar = (ImageButton) itemView.findViewById(R.id.evento_navegar);
            ticket = (ImageButton) itemView.findViewById(R.id.evento_ticket);
            loTelefono = (LinearLayout) itemView.findViewById(R.id.layout_evento_telefono);
        }
    }

    private void cambiarFavorito(boolean hacer,final Button ib, int idEvento){//Si hacer = true, lo inserta en la bbdd sinó lo elimina
        Map<String, String> postData = new HashMap<>();
        if(hacer){
            postData.put("hacer", "1");
        }else{
            postData.put("hacer", "0");
        }
        postData.put("token",AppData.CURRENT_USER.getToken());
        PostAsync task = new PostAsync(new TaskDelegateService() {
            @Override
            public void taskServiceCompleted(JSONObject result) {

            }

            @Override
            public boolean taskServicePost(JSONObject data) {
                if(data != null){
                    try {
                        String status = (String) data.get("STATUS");
                        if (status.equals("OK")) {
                            ib.setSelected(!ib.isSelected());
                            int nFav = (int) data.get("COUNT");
                            ib.setText(""+nFav);
                        }
                    }catch (JSONException je){
                        Log.e("EVENT_LIST",je.getLocalizedMessage());
                    }
                }
                return false;
            }

            @Override
            public void taskGetImage(Bitmap bm) {

            }
        }, postData);
        task.execute("favorito/usuario/evento/"+idEvento);
    }
}
