package onthestage.es.onthestage.adapters;
/*
        Autor: Carlos Tarazona Tárrega.
        Licencia: Copyright 2018. Se permite el estudio y modificación del fichero citando las fuentes
*/
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Build;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import onthestage.es.onthestage.EventoArtistaLocal;
import onthestage.es.onthestage.R;
import onthestage.es.onthestage.Service.PostAsync;
import onthestage.es.onthestage.Service.TaskDelegateService;
import onthestage.es.onthestage.model.EventosContent;
import onthestage.es.onthestage.utils.AppData;

public class EventMinAdapter extends RecyclerView.Adapter<EventMinAdapter.MyViewHolder> {
        private List<EventosContent.EventoMin> mDataset;
        private Context context;
        private Activity activity;
        private int from;


        // Provide a suitable constructor (depends on the kind of dataset)
    public EventMinAdapter(Context context, Activity activity, List< EventosContent.EventoMin > myDataset, int from) {
            this.context = context;
            this.mDataset = new ArrayList<EventosContent.EventoMin>(myDataset);
            this.activity = activity;
            this.from = from;
        }

        public void setDataSet(List<EventosContent.EventoMin> eventos) {
            this.mDataset = new ArrayList<EventosContent.EventoMin>(eventos);
            this.notifyDataSetChanged();
        }

        // Create new views (invoked by the layout manager)
        @Override
        public EventMinAdapter.MyViewHolder onCreateViewHolder(ViewGroup parent,
        int viewType) {
            // create a new view
            View v = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.event_list_short_item, parent, false);
            // set the view's size, margins, paddings and layout parameters

            EventMinAdapter.MyViewHolder vh = new EventMinAdapter.MyViewHolder(v);
            return vh;
        }

        // Replace the contents of a view (invoked by the layout manager)
        @Override
        public void onBindViewHolder(EventMinAdapter.MyViewHolder holder, final int position) {
            // - get element from your dataset at this position
            // - replace the contents of the view with that element
            holder.tvNEvento.setText(AppData.ucFirst(mDataset.get(position).getNombre()).trim());
            holder.idEvento.setText("" + mDataset.get(position).getId());
            final int idEvento = mDataset.get(position).getId();
            String url = mDataset.get(position).getFoto();
            if (url == null || url.equals("")) {
                url = AppData.NO_USER_IMAGE;
            }
            AppData.getGlide(context, url, holder.mFotoPerfil);

            holder.mView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    Intent intent = new Intent(activity, EventoArtistaLocal.class);
                    intent.putExtra(AppData.ARG_ID_EVENTO,idEvento);
                    activity.startActivity(intent);
                }
            });
            holder.favorito.setVisibility(View.GONE);
            if(from == AppData.FROM_FAVORITOS){
                holder.favorito.setVisibility(View.VISIBLE);
                holder.favorito.setSelected(true);

                holder.favorito.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        if (v.isSelected()) {
                            cambiarFavorito(false, (Button) v, idEvento);
                        } else {
                            cambiarFavorito(true, (Button) v, idEvento);
                        }
                    }
                });
            }

            holder.desEvento.setText(AppData.ucFirst(mDataset.get(position).getDescripcion()).trim() + "...");
            if(from == AppData.FROM_ARTISTAS){
                holder.desEvento.setText(AppData.ucFirst(mDataset.get(position).getLocal()).trim());
            }
            if(from == AppData.FROM_LOCALES){
                String sArtista="";
                for (String artista : mDataset.get(position).getArtistas()) {
                    sArtista += AppData.ucFirst(artista.toLowerCase()) + ", ";
                }
                if(Build.VERSION.SDK_INT >= 23)
                    holder.desEvento.setTextColor(context.getColor(R.color.colorBusquedas));
                holder.desEvento.setText(sArtista.substring(0,sArtista.length()-2));
            }

            holder.tvDia.setText(mDataset.get(position).getDay(context));
            holder.tvMes.setText(mDataset.get(position).getMonth(context));


            if(from != AppData.FROM_LOCALES && from!=AppData.FROM_ARTISTAS && from!=AppData.FROM_FAVORITOS){
                holder.compartir.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        AppData.compartirEvento(context,  mDataset.get(position),null);
                    }
                });
            }



        }

        // Return the size of your dataset (invoked by the layout manager)
        @Override
        public int getItemCount() {
            return mDataset.size();
        }

        public class MyViewHolder extends RecyclerView.ViewHolder {
            public final View mView;
            public final ImageView mFotoPerfil;
            public final ImageView compartir;
            public final TextView tvNEvento;
            public final TextView idEvento;
            public final TextView desEvento;
            public final TextView tvDia;
            public final TextView tvMes;
            public final Button favorito;

            public MyViewHolder(View view) {
                super(view);
                mView = view;
                mFotoPerfil = (ImageView) view.findViewById(R.id.image_miniatura);
                compartir = (ImageView) view.findViewById(R.id.evento_share);
                tvNEvento = (TextView) view.findViewById(R.id.nevento);
                idEvento = (TextView) view.findViewById(R.id.idevento);
                desEvento = (TextView) view.findViewById(R.id.desc_evento);
                tvDia = (TextView) view.findViewById(R.id.dia);
                tvMes = (TextView) view.findViewById(R.id.mes);
                favorito = (Button) view.findViewById(R.id.btn_favorito);
            }


        }

        private void cambiarFavorito(boolean hacer, final Button ib, int idEvento) {//Si hacer = true, lo inserta en la bbdd sinó lo elimina
            Map<String, String> postData = new HashMap<>();
            if (hacer) {
                postData.put("hacer", "1");
            } else {
                postData.put("hacer", "0");
            }
            postData.put("token", AppData.CURRENT_USER.getToken());
            PostAsync task = new PostAsync(new TaskDelegateService() {
                @Override
                public void taskServiceCompleted(JSONObject result) {

                }

                @Override
                public boolean taskServicePost(JSONObject data) {
                    if (data != null) {
                        try {
                            String status = (String) data.get("STATUS");
                            if (status.equals("OK")) {
                                ib.setSelected(!ib.isSelected());
                            }
                        } catch (JSONException je) {
                            Log.e("EVENT_LIST", je.getLocalizedMessage());
                        }
                    }
                    return false;
                }

                @Override
                public void taskGetImage(Bitmap bm) {

                }
            }, postData);
            task.execute("favorito/usuario/evento/" + idEvento);
       }

}
