package onthestage.es.onthestage.fragments;

/*
* Author: Carlos Tarazona Tárrega
* License: Copyrigth 2018
* Fragmento de usos múltiples contiene dos RecyclersViews para mostrar listado
* Puede ser usado para favoritos del usuario o para mostrar el historial tanto de locales como de artistas.
* Hace uso del adaptador EventMinAdapter, al cual también se le pasa la procedencia de la petición.
* */

import android.graphics.Bitmap;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import com.google.gson.Gson;
import com.google.gson.JsonElement;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

import onthestage.es.onthestage.R;
import onthestage.es.onthestage.Service.GetAsync;
import onthestage.es.onthestage.Service.TaskDelegateService;
import onthestage.es.onthestage.adapters.EventMinAdapter;
import onthestage.es.onthestage.model.EventosContent;
import onthestage.es.onthestage.utils.AppData;


public class FavoritoEventoFragment extends Fragment{

    static final String FROM = "DESDE";//Para decir si viene desde Favoritos, desde locales o desde Artistas
    static final String TARGET = "ARTISTA_O_LOCAL";//Para decir si viene desde Favoritos, desde locales o desde Artistas
    RecyclerView recyclerViewProximos;
    RecyclerView recyclerViewPasados;
    ProgressBar progressBar;
    int maxRequest = 2;

    int from=0;//Para decir si viene desde Favoritos, desde locales o desde Artistas
    int idTarget = -1; //Será el Id del Artista o del Local, para el caso de Evento no procede

    public FavoritoEventoFragment() {
        // Required empty public constructor
    }

    /**
     * Use this factory method to create a new instance of
     * this fragment using the provided parameters.
     *
     * @return A new instance of fragment FavoritoEventoFragment.
     */
    public static FavoritoEventoFragment newInstance(int from, int idTarget) {
        FavoritoEventoFragment fragment = new FavoritoEventoFragment();
        Bundle args = new Bundle();
        args.putInt(FROM, from);
        args.putInt(TARGET, idTarget);
        fragment.setArguments(args);
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (getArguments() != null) {
            this.from = getArguments().getInt(FROM);
            this.idTarget = getArguments().getInt(TARGET);
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        //AppData.context = getParentFragment().getContext();
        View rootView =  inflater.inflate(R.layout.fragment_favorito_evento, container, false);
        recyclerViewProximos = (RecyclerView) rootView.findViewById(R.id.recycler_next_events);
        recyclerViewPasados = (RecyclerView) rootView.findViewById(R.id.recycler_past_events);
        progressBar = (ProgressBar) rootView.findViewById(R.id.mProgress);
        progressBar.setVisibility(View.VISIBLE);

        maxRequest=2;

        String urlRest= "favorito/usuario/evento";
        switch (from){
            case AppData.FROM_FAVORITOS:
                urlRest= "favorito/usuario/evento";
                break;
            case AppData.FROM_ARTISTAS:
                urlRest= "evento/artista/"+idTarget;
                break;
            case AppData.FROM_LOCALES:
                urlRest= "evento/local/"+idTarget;
                break;
            default:
                urlRest= "favorito/usuario/evento";
                break;
        }

        getEvents(urlRest,true);
        getEvents(urlRest,false);


        return rootView;
    }

    private void getEvents(String urlRest, final boolean next){ //Si next == true, eventos próximos, sinó pasados
        String query="?proximos=1";
        if(next){
            query = "?proximos=1";
        }else{
            query = "?anteriores=1";
        }
        GetAsync ga = new GetAsync(new TaskDelegateService() {
            @Override
            public void taskServiceCompleted(JSONObject data) {
                if(data != null) {
                    try {
                        String status = (String) data.get("STATUS");
                        if (status.equals("OK")) {
                            List<EventosContent.EventoMin> eventos = new ArrayList<EventosContent.EventoMin>();
                            Gson gson = new Gson();
                            JSONArray jsonArray = data.getJSONArray("DATA");
                            for (int i = 0; i < jsonArray.length(); i++) {
                                JSONObject jsonObject = (JSONObject) jsonArray.get(i);
                                JsonElement element = gson.fromJson(jsonObject.toString(), JsonElement.class);
                                EventosContent.EventoMin eventoMin = gson.fromJson(element, EventosContent.EventoMin.class);
                                eventos.add(eventoMin);
                            }

                            EventMinAdapter eventMinAdapter = new EventMinAdapter(getContext(),getActivity(),eventos,from);
                            if(next){
                                recyclerViewProximos.setAdapter(eventMinAdapter);
                                recyclerViewProximos.setLayoutManager(new LinearLayoutManager(getContext()));
                            }else{
                                recyclerViewPasados.setAdapter(eventMinAdapter);
                                recyclerViewPasados.setLayoutManager(new LinearLayoutManager(getContext()));
                            }
                            maxRequest--;
                            if(maxRequest<=0){
                                progressBar.setVisibility(View.GONE);
                                maxRequest=2;
                            }


                        }
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }

                    Log.d("GENEROS",AppData.ARTISTAMIN.toString());
                }
            }

            @Override
            public boolean taskServicePost(JSONObject data) {
                return false;
            }

            @Override
            public void taskGetImage(Bitmap bm) {

            }
        },AppData.CURRENT_USER.getToken());

        ga.execute(urlRest+query);

    }




}
