package onthestage.es.onthestage.fragments;
/*
        Autor: Carlos Tarazona Tárrega.
        Licencia: Copyright 2018. Se permite el estudio y modificación del fichero citando las fuentes
*/
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.location.LocationManager;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.MapView;
import com.google.android.gms.maps.MapsInitializer;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.UiSettings;
import com.google.android.gms.maps.model.BitmapDescriptor;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import onthestage.es.onthestage.EventoArtistaLocal;
import onthestage.es.onthestage.R;
import onthestage.es.onthestage.Service.LocationService;
import onthestage.es.onthestage.model.Artista;
import onthestage.es.onthestage.model.EventosContent;
import onthestage.es.onthestage.utils.AppData;

public class MapViewFragment extends Fragment {

    MapView mMapView;
    private GoogleMap googleMap;
    List< EventosContent.EventoMin> misEventos;


    double latitud,longitud;



    public void setMisEventos(List<EventosContent.EventoMin> misEventos) {
        this.misEventos = misEventos;
    }

    public MapViewFragment() {

    }

    static MapViewFragment mapViewFragment = null;

    public static MapViewFragment getInstance() {
        if(mapViewFragment==null){
            mapViewFragment = new MapViewFragment();
        }
        return mapViewFragment;
    }

    public interface OnFragmentInteractionListener {
        // TODO: Update argument type and name
        void onFragmentInteraction(Uri uri);
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
//        if (getArguments().containsKey( AppData.ARG_ITEM_ID )) {
//            artista = (Artista)getArguments().getSerializable(AppData.ARG_ITEM_ID);
//        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.layout_mapa, container, false);

        mMapView = (MapView) rootView.findViewById(R.id.mapView);
        mMapView.onCreate(savedInstanceState);

        mMapView.onResume(); // needed to get the map to display immediately

        try {
            MapsInitializer.initialize(getActivity().getApplicationContext());
        } catch (Exception e) {
            e.printStackTrace();
        }

        mMapView.getMapAsync(new OnMapReadyCallback() {
            @Override
            public void onMapReady(GoogleMap mMap) {
                googleMap = mMap;
                googleMap.getUiSettings().setZoomControlsEnabled(true);
                googleMap.getUiSettings().setMapToolbarEnabled(true);

                HashMap<Integer,Integer> iconos = new HashMap<Integer, Integer>();
                iconos.put(3,R.drawable.magia);
                iconos.put(4,R.drawable.baile);
                iconos.put(5,R.drawable.baile);

                LocationService ls = LocationService.getLocationManager(getContext());
                LatLng myPosition = null;
                if(ls.locationServiceAvailable){
                   myPosition = new LatLng(ls.latitude,ls.longitude);
                }

                // For showing a move to my location button

                //googleMap.setMyLocationEnabled(true);

                // For dropping a marker at a point on the Map
                for(EventosContent.EventoMin e: AppData.EVENTOS_MIN){
                    LatLng latLng = new LatLng(e.getLatitud(),e.getLongitud());
                    MarkerOptions markerOptions = new MarkerOptions().position(latLng).title(e.getLocal()).snippet(e.getNombre());

                    Marker marker = googleMap.addMarker(markerOptions);
                    marker.setTag(e.getId());
                    Integer tipoEvento = e.getTipoevento();
                    if(iconos.containsKey(tipoEvento)){
                        marker.setIcon(BitmapDescriptorFactory.fromResource(iconos.get(tipoEvento)));
                    }else{
                        marker.setIcon(BitmapDescriptorFactory.fromResource(R.drawable.musica));
                    }

                }


                // For zooming automatically to the location of the marker
                if(myPosition!=null){
                    CameraPosition cameraPosition = new CameraPosition.Builder().target(myPosition).zoom(16).build();
                    googleMap.animateCamera(CameraUpdateFactory.newCameraPosition(cameraPosition));
                }

                googleMap.setOnMarkerClickListener(new GoogleMap.OnMarkerClickListener() {
                    @Override
                    public boolean onMarkerClick(Marker marker) {
                        //Toast.makeText(getContext(),"Evento " + marker.getTag(),Toast.LENGTH_SHORT).show();
                        Intent intent = new Intent(getContext(),EventoArtistaLocal.class);
                             int eventoId = -1;
                        try{
                            eventoId = (int) marker.getTag();
                        }catch (ClassCastException c){
                            Log.e("ERROR_MAP_FRAGEMENT", c.getLocalizedMessage());
                        }
                        catch (Exception e){
                            Log.e("ERROR_MAP_FRAGEMENT", e.getLocalizedMessage());
                        }
                        intent.putExtra(AppData.ARG_ID_EVENTO,eventoId);
                        getContext().startActivity(intent);
                        return false;
                    }
                });



            }
        });

        return rootView;
    }

    @Override
    public void onResume() {
        super.onResume();
        mMapView.onResume();
    }

    @Override
    public void onPause() {
        super.onPause();
        mMapView.onPause();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        mMapView.onDestroy();
    }

    @Override
    public void onLowMemory() {
        super.onLowMemory();
        mMapView.onLowMemory();
    }

    public List<EventosContent.EventoMin> getMisEventos() {
        return misEventos;
    }

}
